@@ -1,6 +1,7 @@
 import sys
 import os
 import logging
+import logging.handlers
 
 from .settings import TEMP_DIR
 
@@ -20,7 +21,7 @@ class Logger:
         formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
         # Add File Handler
-        file_handler = logging.FileHandler(self.file_path)
+        file_handler = logging.handlers.RotatingFileHandler(self.file_path, maxBytes=1000000, backupCount=5)
         file_handler.setLevel(logging.DEBUG)
         file_handler.setFormatter(formatter)
         self.logger.addHandler(file_handler)
